Changelog
=========

Version 0.1
-----------

0.1.0
^^^^^
Released on 2013-12-04. First release.

Contains :py:func:`sheepdog.map_sync`, the first top level
utility function, plus the basic underlying sqlite storage and tornado/flask
web server bits.
